summaryrefslogtreecommitdiffstats
path: root/src/demos/util/TGAImage.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/demos/util/TGAImage.java')
-rw-r--r--src/demos/util/TGAImage.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/demos/util/TGAImage.java b/src/demos/util/TGAImage.java
index 24403eb..a99f4f3 100644
--- a/src/demos/util/TGAImage.java
+++ b/src/demos/util/TGAImage.java
@@ -40,7 +40,8 @@
package demos.util;
import java.io.*;
-import net.java.games.jogl.*;
+import javax.media.opengl.*;
+import com.sun.opengl.utils.*;
/**
* Targa image reader adapted from sources of the <a href =
@@ -271,10 +272,10 @@ public class TGAImage {
data = new byte[rawWidth * header.height()];
if (header.pixelDepth() == 24) {
- format = GL.GL_BGR_EXT;
+ format = GL.GL_BGR;
} else {
assert header.pixelDepth() == 32;
- format = GL.GL_BGRA_EXT;
+ format = GL.GL_BGRA;
}
for (i = 0; i < header.height(); ++i) {
@@ -295,7 +296,7 @@ public class TGAImage {
/** Returns the height of the image. */
public int getHeight() { return header.height(); }
/** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
public int getGLFormat() { return format; }
/** Returns the raw data for this texture in the correct
@@ -295,7 +296,7 @@ public class TGAImage {
/** Returns the height of the image. */
public int getHeight() { return header.height(); }
- /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR_EXT or GL.GL_BGRA_EXT. */
+ /** Returns the OpenGL format for this texture; e.g. GL.GL_BGR or GL.GL_BGRA. */
public int getGLFormat() { return format; }
/** Returns the raw data for this texture in the correct